@@ -155,6 +155,12 @@ class Mixer : public QObject
 
       virtual bool isAvailableDevice( const QString& mixdeviceID );
 
+      /// Says if we are dynamic (e.g. widgets can come and go)
+      virtual void setDynamic( bool dynamic = true );
+      virtual bool dynamic();
+
+      virtual bool moveStream( const QString id, const QString& destId );
+
       void commitVolumeChange( MixDevice* md );
 
    public slots:
@@ -166,6 +172,7 @@ class Mixer : public QObject
    signals:
       void newBalance( Volume& );
       void controlChanged(void);
+      void controlsReconfigured( const QString& mixer_ID );
 
    protected:
       int m_balance; // from -100 (just left) to 100 (just right)
@@ -173,6 +180,7 @@ class Mixer : public QObject
 
    private slots:
       void controlChangedForwarder();
+      void controlsReconfiguredForwarder( const QString& mixer_ID );
 
    public:
       static QList<Mixer *>& mixers();
@@ -186,6 +194,7 @@ class Mixer : public QObject
       static QString _globalMasterCardDevice;
       
       QString m_dbusName;
+      bool m_dynamic;
 };
 
 #endif
