@@ -43,7 +43,6 @@ public:
     ~ViewDockAreaPopup();
     MixDevice* dockDevice();
 
-    virtual void setMixSet();
     virtual QWidget* add(MixDevice *mdw);
     virtual void constructionFinished();
     virtual void refreshVolumeLevels();
@@ -52,12 +51,12 @@ public:
     //QSize sizeHint() const;
 
 protected:
-    MixDeviceWidget *_mdw;
     KMixWindow  *_dock;
     //MixDevice       *_dockDevice;
     QPushButton     *_showPanelBox;
 
     void wheelEvent ( QWheelEvent * e );
+    virtual void _setMixSet();
 
 private:
     QGridLayout* _layoutMDW;
